@@ -1,10 +1,9 @@
-if [[ "$(uname)" == "Darwin" ]]; then
+if [[ "$target_platform" == osx-* ]]; then
     ln -s $PREFIX/lib/${blas_impl_lib} $PREFIX/lib/${PKG_NAME}.${PKG_VERSION:0:1}.dylib
-    ln -s $PREFIX/lib/${blas_impl_lib} $PREFIX/lib/${PKG_NAME}.dylib
 else
     ln -s $PREFIX/lib/${blas_impl_lib} $PREFIX/lib/${PKG_NAME}.so.${PKG_VERSION:0:1}
-    ln -s $PREFIX/lib/${blas_impl_lib} $PREFIX/lib/${PKG_NAME}.so
 fi
+ln -s $PREFIX/lib/${blas_impl_lib} $PREFIX/lib/${PKG_NAME}${SHLIB_EXT}
 
 if [[ "${blas_impl}" == "mkl" ]]; then
     for CHANGE in "activate" "deactivate"
